import { Action } from '@ngrx/store';
import { Course } from '@app/core/models/course';

export enum CourseActionTypes {
  AddCourseRequest = '[Course] Add Course Request',
  AddCourseResponse = '[Course] Add Course Response',

  RemoveCourseRequest = '[Course] Remove Course Request',
  RemoveCourseResponse = '[Course] Remove Course Response',

  ChangeCourseTermRequest = '[Course] Change Course Term Request',
  ChangeCourseTermResponse = '[Course] Change Course Term Response',

  AddSavedForLaterRequest = '[Course] Add Saved For Later Request',
  AddSavedForLaterResponse = '[Course] Add Saved For Later Response',

  RemoveSavedForLaterRequest = '[Course] Remove Saved For Later Request',
  RemoveSavedForLaterResponse = '[Course] Remove Saved For Later Response',

  MoveFromSavedToTermRequest = '[Course] Move Course From Saved to Term Request',
  MoveFromSavedToTermResponse = '[Course] Move Course From Saved to Term Response',
}

export class ChangeCourseTermRequest implements Action {
  public readonly type = CourseActionTypes.ChangeCourseTermRequest;
  constructor(public payload: { to: string; from: string; id: number }) {}
}

export class ChangeCourseTermResponse implements Action {
  public readonly type = CourseActionTypes.ChangeCourseTermResponse;
  constructor(public payload: { to: string; from: string; id: number }) {}
}

export class AddCourseRequest implements Action {
  public readonly type = CourseActionTypes.AddCourseRequest;
  constructor(
    public payload: { subjectCode: string; courseId: string; termCode: string },
  ) {}
}

export class AddCourseResponse implements Action {
  public readonly type = CourseActionTypes.AddCourseResponse;
  constructor(public payload: { course: Course }) {}
}

export class RemoveCourseRequest implements Action {
  public readonly type = CourseActionTypes.RemoveCourseRequest;
  constructor(public payload: { recordId: number }) {}
}

export class RemoveCourseResponse implements Action {
  public readonly type = CourseActionTypes.RemoveCourseResponse;
  constructor(public payload: { recordId: number }) {}
}

export class AddSavedForLaterRequest implements Action {
  public readonly type = CourseActionTypes.AddSavedForLaterRequest;
  constructor(
    public payload: {
      subjectCode: string;
      courseId: string;
      title: string;
      catalogNumber: string;
    },
  ) {}
}

export class AddSavedForLaterResponse implements Action {
  public readonly type = CourseActionTypes.AddSavedForLaterResponse;
  constructor(
    public payload: {
      subjectCode: string;
      courseId: string;
      title: string;
      catalogNumber: string;
    },
  ) {}
}

export class RemoveSavedForLaterRequest implements Action {
  public readonly type = CourseActionTypes.RemoveSavedForLaterRequest;
  constructor(public payload: { subjectCode: string; courseId: string }) {}
}

export class RemoveSavedForLaterResponse implements Action {
  public readonly type = CourseActionTypes.RemoveSavedForLaterResponse;
  constructor(public payload: { subjectCode: string; courseId: string }) {}
}
